powered by
Density, distribution function, quantile function and random generation for the unifed distribution.
dunifed(x, theta)unifed.lcdf(x, theta)punifed(q, theta)qunifed(p, theta)runifed(n, theta)
unifed.lcdf(x, theta)
punifed(q, theta)
qunifed(p, theta)
runifed(n, theta)
A vector of quantiles. They must be numbers between 0 and 1.
The value of the canonical parameter. It must be of length one.
A vector of quantiles.
A vector of probabilities.
number of observations
dunifed gives the density function.
dunifed
unifed.lcdf returns the log of the cumulative distribution function of the unifed.
unifed.lcdf
punifed gives the distribution function.
punifed
qunifed gives the quantile function.
qunifed
runifed generates random observations.
runifed
Quijano Xacur, O.A. The unifed distribution. J Stat Distrib App 6, 13 (2019). doi:10.1186/s40488-019-0102-6.
# NOT RUN { dunifed( c(0.1,0.3,0.7), 10) x <- c(0.3,0.6,0.9) unifed.lcdf(x,5) x <- c(0.1,0.4,0.7,1) punifed(x,-5) p <- 1:9/10 qunifed(p,5) runifed(20,-3.3) # }
Run the code above in your browser using DataLab