Wrapper function for summary.glm.
summary_unifed_glm(object, ...)an object of class "glm".
Other arguments for stats::summary.glm.
This wrapper function was created in order to automatically set to 1 the dispersion parameter of a fitted unifed GLM. When the package is loaded the summary method of the glm class is rewritten using this function.