unifed.kappa returns a vector that contains the
cumulant generator of the unifed distribution applied to each
element of theta.
unifed.kappa.prime returns a vector that contains
the derivative of the cumulant generator of the unifed
distribution for each element of theta.
unifed.kappa.double.prime returns a vector that
contains the second derivative of the cumulant generator of the
unifed distribution for each element of theta.
unifed.kappa.prime.inverse returns a vector with
unifed.kappa.prime.inverse.one evaluated at every entry
of mu.
unifed.kappa.prime.inverse.one if the tolerance
level is reached within maxit iterations, the function
returns the value of the last iteration. Otherwise it returns
NA.