Learn R Programming

unifed (version 1.1.6)

unifed.mle: Maximum Likelihood Estimate for the unifed distribution

Description

Maximum Likelihood Estimate for the unifed distribution

Usage

unifed.mle(x)

Arguments

x

A numeric vector with values in the interval [0,1].

Computes the maximum likelihood estimator of the canonical parameter of the unifed distribution. It is assumed that the elements of x come from independent and identically distributed unifed random variables.

Examples

Run this code
# NOT RUN {
a.unifed.sample <- runifed(1000,10)
theta.mle <- unifed.mle(a.unifed.sample)

# }

Run the code above in your browser using DataLab